@@ -12,7 +12,19 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
+
 from mistral_lib.actions.base import Action
+from mistral_lib.actions.base import ActionDescriptor
+from mistral_lib.actions.base import ActionProvider
+from mistral_lib.actions.providers.composite import CompositeActionProvider
+from mistral_lib.actions.providers.python import PythonActionDescriptor
 from mistral_lib.actions.types import Result
 
-__all__ = ['Action', 'Result']
+__all__ = [
+    'Action',
+    'Result',
+    'ActionDescriptor',
+    'ActionProvider',
+    'PythonActionDescriptor',
+    'CompositeActionProvider'
+]
